@@ -1,5 +1,5 @@
 package Yancy::Backend::Pg;
-our $VERSION = '1.004';
+our $VERSION = '1.005';
 # ABSTRACT: A backend for Postgres using Mojo::Pg
 
 #pod =head1 SYNOPSIS
@@ -19,6 +19,19 @@ our $VERSION = '1.004';
 #pod         read_schema => 1,
 #pod     };
 #pod
+#pod     ### Hashref
+#pod     use Mojolicious::Lite;
+#pod     plugin Yancy => {
+#pod         backend => {
+#pod             Pg => {
+#pod                 dsn => 'dbi:Pg:dbname',
+#pod                 username => 'fry',
+#pod                 password => 'b3nd3r1sgr34t',
+#pod             },
+#pod         },
+#pod         read_schema => 1,
+#pod     };
+#pod
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -99,7 +112,7 @@ our $VERSION = '1.004';
 #pod =cut
 
 use Mojo::Base '-base';
-use Scalar::Util qw( looks_like_number );
+use Scalar::Util qw( looks_like_number blessed );
 BEGIN {
     eval { require Mojo::Pg; Mojo::Pg->VERSION( 3 ); 1 }
         or die "Could not load Pg backend: Mojo::Pg version 3 or higher required\n";
@@ -114,6 +127,13 @@ sub new {
         my ( $connect ) = $backend =~ m{^[^:]+://(.+)$};
         $backend = Mojo::Pg->new( "postgresql://$connect" );
     }
+    elsif ( !blessed $backend ) {
+        my $attr = $backend;
+        $backend = Mojo::Pg->new;
+        for my $method ( keys %$attr ) {
+            $backend->$method( $attr->{ $method } );
+        }
+    }
     my %vars = (
         pg => $backend,
         collections => $collections,
@@ -286,7 +306,7 @@ Yancy::Backend::Pg - A backend for Postgres using Mojo::Pg
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -305,6 +325,19 @@ version 1.004
         read_schema => 1,
     };
 
+    ### Hashref
+    use Mojolicious::Lite;
+    plugin Yancy => {
+        backend => {
+            Pg => {
+                dsn => 'dbi:Pg:dbname',
+                username => 'fry',
+                password => 'b3nd3r1sgr34t',
+            },
+        },
+        read_schema => 1,
+    };
+
 =head1 DESCRIPTION
 
 This Yancy backend allows you to connect to a Postgres database to manage
